/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: Pops, TCSDeveloper
 */

using System;

namespace TopCoder.Rules.DependencyMap.View
{

    /// <summary>
    /// The layout manager is responsible for laying out the diagram and painting it to the specified IGraphics
    /// object. This interface defines the contract for implemenations to follow.
    /// </summary>
    public interface ILayoutManager
    {

        /// <summary>
        /// This method is called by the DependencyRenderer to layout and print the diagram. This method is provided
        /// the dependency to layout, the shape factory to retrieve the shapes from and the IGraphics.
        /// </summary>
        /// <param name="dependency">The dependency to layout</param>
        /// <param name="shapeFactory">The shape factory to use</param>
        /// <param name="graphics">The IGraphics object to paint to</param>
        /// <exception cref="ArgumentNullException">if any of the arguments are null</exception>
        /// <exception cref="RendererException">if some exception occurred while laying out the dependency
        /// diagram</exception>
        void Layout(Dependency dependency, ShapeFactory shapeFactory, IGraphics graphics);

    }

}
