/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view;

/**
 * This interface defines the contract that implementors of a diagram renderer should follow. A DiagramRenderer
 * implementation will provide a method that will supply the component a Graphics2D implementation that will be
 * used to 'paint' the diagram with.  The implementation will then also provide a 'disposing' method to signal
 * when the Graphics2D is no longer needed and should be disposed of (giving the implementor the chance to write
 * out a file or to otherwise take care of external resources).
 *
 * @author Pops
 * @author TCSDeveloper
 */
public interface DiagramRenderer {
    /**
     * This method will be called by the DependencyRenderer to retreive a graphics2d object to paint the diagram
     * with. The dependency is passed with this call to allow the renderer implementation to configure itself
     * (maybe configuring a file name based on the dependency being rendered).
     *
     * @param dependency The dependency that will be rendered
     * @param width The width of the expected image
     * @param height The height of the expected image
     * @return A graphics object that can be used to paint the diagram with
     * @throws NullPointerException if dependency is null
     * @throws RendererException if an error occurs getting the graphics
     * @throws IllegalArgumentException if width or height is <= 0 
     */
    RendererGraphics getGraphics(Dependency dependency, int width, int height);

}
